summaryrefslogtreecommitdiffstats
path: root/extensions/common/extension_urls.h
diff options
context:
space:
mode:
authorrdevlin.cronin <rdevlin.cronin@chromium.org>2015-07-15 16:51:39 -0700
committerCommit bot <commit-bot@chromium.org>2015-07-15 23:52:07 +0000
commitde23cacc840c6c184c67d30de9ff07f7c4f71307 (patch)
treeffcf0a3569ed8eb9b76113e13e365418bed24861 /extensions/common/extension_urls.h
parent4cf2aa39e2220a3b5ef50a95fc11cf4ff35a85d5 (diff)
downloadchromium_src-de23cacc840c6c184c67d30de9ff07f7c4f71307.zip
chromium_src-de23cacc840c6c184c67d30de9ff07f7c4f71307.tar.gz
chromium_src-de23cacc840c6c184c67d30de9ff07f7c4f71307.tar.bz2
[Extensions] Add a referrer to the url for reporting extension abuse
Add a referrer to the url that we use to report abuse from the extension uninstall dialog so that we can track its usage separately. BUG=510618 Review URL: https://codereview.chromium.org/1237313003 Cr-Commit-Position: refs/heads/master@{#338950}
Diffstat (limited to 'extensions/common/extension_urls.h')
-rw-r--r--extensions/common/extension_urls.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/extensions/common/extension_urls.h b/extensions/common/extension_urls.h
index c651fcf..2fd72c8 100644
--- a/extensions/common/extension_urls.h
+++ b/extensions/common/extension_urls.h
@@ -70,8 +70,10 @@ GURL GetWebstoreSearchPageUrl(const std::string& query);
// have been overridden by a command line flag for testing purposes.
GURL GetWebstoreUpdateUrl();
-// Returns the url to visit to report abuse for the given |extension_id|.
-GURL GetWebstoreReportAbuseUrl(const std::string& extension_id);
+// Returns the url to visit to report abuse for the given |extension_id|
+// and |referrer_id|.
+GURL GetWebstoreReportAbuseUrl(const std::string& extension_id,
+ const std::string& referrer_id);
// Returns whether the URL is the webstore update URL (just considering host
// and path, not scheme, query, etc.)